package com.sooka.sponest.event.centereventteventcatalogue.controller;

import com.alibaba.fastjson.JSONObject;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.utils.StringUtils;
import com.sooka.sponest.event.centereventteventcatalogue.domain.dahua.DaHuaFireEventVO;
import com.sooka.sponest.event.centereventteventcatalogue.domain.dahua.DaHuaOtherEventVO;
import com.sooka.sponest.event.centereventteventcatalogue.domain.haikang.HaiKangEventVo;
import com.sooka.sponest.event.centereventteventcatalogue.service.AlarmEventService;
import com.sooka.sponest.event.centereventtreportmessage.domain.CentereventTReportmessage;
import com.sooka.sponest.event.centereventtreportmessage.service.ICentereventTReportmessageService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@Api(tags = "海康")
@RestController
@RequestMapping("AlarmEventController")
public class AlarmEventController {

    protected final Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private AlarmEventService alarmEventService;

    @Autowired
    private ICentereventTReportmessageService centereventTReportmessageService;

    @ApiOperation("火险事件上报")
    @PostMapping("/haikang@insertFireEvent")
    public R insertFireEvent(@RequestBody JSONObject jsonObject) {
        String eventCode = null;
        try {
            HaiKangEventVo haiKangEventVo = JSONObject.toJavaObject(jsonObject.getJSONObject("params"), HaiKangEventVo.class);
            eventCode = alarmEventService.insertHaiKangFireEvent(haiKangEventVo.getEvents()[0]);
        } catch (Exception e) {
            logger.error(e.getMessage());
        }
        if (StringUtils.isBlank(eventCode)) {
            eventCode = String.valueOf(System.currentTimeMillis());
        }
        try {
            CentereventTReportmessage tReportMessage = new CentereventTReportmessage();
            tReportMessage.setId(eventCode);
            tReportMessage.setSource("海康摄像头-火情");
            tReportMessage.setContext(jsonObject.toJSONString());
            centereventTReportmessageService.insertCentereventTReportmessage(tReportMessage);
        } catch (Exception e) {
            logger.error(e.getMessage());
        }
        return R.ok();
    }

    @ApiOperation("城管事件上报")
    @PostMapping("/haikang@insertCityEvent")
    public R insertCityEvent(@RequestBody JSONObject jsonObject) {
        String eventCode = null;
        try {
            HaiKangEventVo haiKangEventVo = JSONObject.toJavaObject(jsonObject.getJSONObject("params"), HaiKangEventVo.class);
            eventCode = alarmEventService.insertHaiKangCityEvent(haiKangEventVo);
        } catch (Exception e) {
            logger.error(e.getMessage());
        }
        if (StringUtils.isBlank(eventCode)) {
            eventCode = String.valueOf(System.currentTimeMillis());
        }
        try {
            CentereventTReportmessage tReportMessage = new CentereventTReportmessage();
            tReportMessage.setId(eventCode);
            tReportMessage.setSource("海康摄像头-城管");
            tReportMessage.setContext(jsonObject.toJSONString());
            centereventTReportmessageService.insertCentereventTReportmessage(tReportMessage);
        } catch (Exception e) {
            logger.error(e.getMessage());
        }
        return R.ok();
    }

    @PostMapping("/dahua@alarmEvent")
    public R alarmEvent(@RequestBody String jsonStr) {
        String eventCode = null;
        DaHuaFireEventVO daHuaFireEventVO = new DaHuaFireEventVO();
        try {
            daHuaFireEventVO = JSONObject.parseObject(jsonStr, DaHuaFireEventVO.class);
            eventCode = alarmEventService.insertDaHuaEvent(daHuaFireEventVO);
        } catch (Exception e) {
            logger.error(e.getMessage());
        }
        if (StringUtils.isBlank(eventCode)) {
            eventCode = String.valueOf(System.currentTimeMillis());
        }
        try {
            CentereventTReportmessage tReportMessage = new CentereventTReportmessage();
            tReportMessage.setId(eventCode);
            tReportMessage.setSource("大华摄像头-" + daHuaFireEventVO.getInfo().getAlarmTypeName());
            tReportMessage.setContext(jsonStr);
            centereventTReportmessageService.insertCentereventTReportmessage(tReportMessage);
        } catch (Exception e) {
            logger.error(e.getMessage());
        }
        return R.ok();
    }

    @PostMapping("/dahua@alarmEventOther")
    public R alarmEventOther(@RequestBody String jsonStr) {
        String eventCode = null;
        DaHuaOtherEventVO daHuaOtherEventVO = new DaHuaOtherEventVO();
        try {
            daHuaOtherEventVO = JSONObject.parseObject(jsonStr, DaHuaOtherEventVO.class);
            eventCode = alarmEventService.insertDaHuaOtherEvent(daHuaOtherEventVO);
        } catch (Exception e) {
            logger.error(e.getMessage());
        }
        if (StringUtils.isBlank(eventCode)) {
            eventCode = String.valueOf(System.currentTimeMillis());
        }
        try {
            CentereventTReportmessage tReportMessage = new CentereventTReportmessage();
            tReportMessage.setId(eventCode);
            String alarmName = StringUtils.isBlank(daHuaOtherEventVO.getAlarmName()) ? daHuaOtherEventVO.getAlarmType() : daHuaOtherEventVO.getAlarmName();
            tReportMessage.setSource("大华摄像头-" + alarmName);
            tReportMessage.setContext(jsonStr);
            centereventTReportmessageService.insertCentereventTReportmessage(tReportMessage);
        } catch (Exception e) {
            logger.error(e.getMessage());
        }
        return R.ok();
    }

    @PostMapping("/insertEventByReport")
    public R insertEventByReport(String start, String end, String source) {
        if (StringUtils.isBlank(start) || StringUtils.isBlank(end)) {
            return R.fail("请检查参数");
        }
        List<CentereventTReportmessage> reportmessages = centereventTReportmessageService.selectCentereventTReportmessageListRange(start, end, source);
        int i = 0;
        for (CentereventTReportmessage message : reportmessages) {
            String eventCode = null;
            if (message.getSource().contains("火情报警")) {
                try {
                    DaHuaFireEventVO daHuaFireEventVO = JSONObject.parseObject(message.getContext(), DaHuaFireEventVO.class);
                    daHuaFireEventVO.setCreateTime(message.getCreateTime());
                    eventCode = alarmEventService.insertDaHuaEvent(daHuaFireEventVO);
                } catch (Exception e) {
                    logger.error(e.getMessage());
                }
            } else {
                try {
                    DaHuaOtherEventVO daHuaOtherEventVO = JSONObject.parseObject(message.getContext(), DaHuaOtherEventVO.class);
                    daHuaOtherEventVO.setCreateTime(message.getCreateTime());
                    eventCode = alarmEventService.insertDaHuaOtherEvent(daHuaOtherEventVO);
                } catch (Exception e) {
                    logger.error(e.getMessage());
                }
            }
            if (StringUtils.isNotBlank(eventCode)) {
                centereventTReportmessageService.updateCentereventTReportmessage(message.getId(), eventCode);
                i++;
            }
        }
        return R.ok(i);// 3951
    }
}
