package com.sooka.sponest.event.centereventteventcatalogue.controller;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.dahuatech.icc.exception.ClientException;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.utils.StringUtils;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.utils.SecurityUtils;
import com.ruoyi.system.api.model.LoginUser;
import com.sooka.sponest.event.centereventteventcatalogue.domain.DaHuaEventBO;
import com.sooka.sponest.event.centereventteventcatalogue.domain.sensor.SensorEventVo;
import com.sooka.sponest.event.centereventteventcatalogue.service.AlarmEventService;
import com.sooka.sponest.event.centereventteventtype.domain.CentereventTEventtype;
import com.sooka.sponest.event.centereventteventtype.service.ICentereventTEventtypeService;
import com.sooka.sponest.event.centereventtreportmessage.domain.CentereventTReportmessage;
import com.sooka.sponest.event.centereventtreportmessage.service.ICentereventTReportmessageService;
import com.sooka.sponest.exchange.api.domain.FireEventVO;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.text.SimpleDateFormat;
import java.util.Date;

@RestController
@RequestMapping("/fireIncident")
public class FireIncidentController {

    protected final Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private AlarmEventService alarmEventService;

    @Autowired
    private ICentereventTReportmessageService centereventTReportmessageService;

    @Autowired
    private ICentereventTEventtypeService centereventTEventtypeService;

    /**
     * 传感器事件上报
     *
     * @param sensorEventVo
     * @return R
     */
    @Log(title = "事件上报", businessType = BusinessType.INSERT)
    @PostMapping("/insertSensorEvent")
    public R insertSensorEvent(@RequestBody SensorEventVo sensorEventVo) {
        String eventCode = null;
        try {
            eventCode = alarmEventService.insertSensorEvent(sensorEventVo);
        } catch (Exception e) {
            logger.error(e.getMessage());
        }
        if (StringUtils.isBlank(eventCode)) {
            eventCode = System.currentTimeMillis() + "_";
        }
        try {
            String[] array = eventCode.split("_");
            CentereventTReportmessage tReportMessage = new CentereventTReportmessage();
            tReportMessage.setId(array[0]);
            tReportMessage.setSource("传感器-" + array[1]);
            tReportMessage.setContext(JSON.toJSONString(sensorEventVo));
            centereventTReportmessageService.insertCentereventTReportmessage(tReportMessage);
        } catch (Exception e) {
            logger.error(e.getMessage());
        }
        return R.ok();
    }

    /**
     * 事件回查图片
     *
     * @param eventBO eventCode 事件编号
     *                logId  事件日志id
     * @return AjaxResult
     * @throws ClientException 异常类
     */
    @PostMapping("/updateFireEventImage")
    public AjaxResult updateFireEventImage(@RequestBody DaHuaEventBO eventBO) throws ClientException {
        if (StringUtils.isBlank(eventBO.getEventCode()) || StringUtils.isBlank(eventBO.getLogId())) {
            return AjaxResult.success("参数异常");
        }
        // 通过eventCode获取报文信息
        CentereventTReportmessage centereventTReportmessage = centereventTReportmessageService.selectCentereventTReportmessageById(eventBO.getEventCode());
        // 解析报文
        JSONObject context = JSONObject.parseObject(centereventTReportmessage.getContext()).getJSONObject("info");
        eventBO.setAlarmCode(context.getString("alarmCode"));
        eventBO.setAlarmDate(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date(context.getLong("alarmDate"))));
        eventBO.setDbType("0");
        return AjaxResult.success(alarmEventService.updateFireEventImage(eventBO));
    }

    /**
     * 119事件上报
     *
     * @param fireEventVO
     * @return
     */
    @Log(title = "事件上报", businessType = BusinessType.INSERT)
    @PostMapping("/insert3rdSystemEvent")
    public R insert3rdSystemEvent(@Validated @RequestBody FireEventVO fireEventVO) {
        // 验证token
        LoginUser loginUser = SecurityUtils.getLoginUser();
        if (StringUtils.isNull(loginUser)) {
            logger.error("权限认证失败---{}", fireEventVO);
            return R.fail("权限认证失败");
        }
        // 根据事件小类，反查事件大类
        CentereventTEventtype eventtype = centereventTEventtypeService.selectCentereventTEventtypeById(fireEventVO.getEventType());
        if (StringUtils.isNull(eventtype)) {
            logger.error("不支持的事件类型---{}", fireEventVO);
            return R.fail("不支持的事件类型");
        }
        StringBuilder eventCode = new StringBuilder();
        try {
            fireEventVO.setEventSupType(eventtype.getParentId());
            // 处理上报逻辑
            eventCode.append(alarmEventService.insert3rdSystemEvent(fireEventVO));
        } catch (Exception e) {
            logger.error(e.getMessage());
        }
        if (StringUtils.isBlank(eventCode.toString())) {
            eventCode.append(System.currentTimeMillis());
        }
        // 写入报文
        try {
            CentereventTReportmessage tReportMessage = new CentereventTReportmessage();
            tReportMessage.setId(eventCode.toString());
            tReportMessage.setSource("119接处警-" + eventtype.getEventTypeName());
            tReportMessage.setContext(JSON.toJSONString(fireEventVO));
            centereventTReportmessageService.insertCentereventTReportmessage(tReportMessage);
        } catch (Exception e) {
            logger.error(e.getMessage());
        }
        return R.ok(null, "接收成功");
    }
}
