package com.sooka.sponest.event.centereventteventcatalogue.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.dahuatech.icc.exception.ClientException;
import com.dahuatech.icc.oauth.http.IccHttpHttpRequest;
import com.ruoyi.common.core.utils.DateUtils;
import com.ruoyi.common.core.utils.SpringUtils;
import com.ruoyi.common.core.utils.StringUtils;
import com.ruoyi.common.core.utils.uuid.IdUtils;
import com.ruoyi.common.security.utils.SecurityUtils;
import com.sooka.sponest.event.centereventtdeptevent.domain.CentereventDeptEvent;
import com.sooka.sponest.event.centereventtdeptevent.service.ICentereventDeptEventService;
import com.sooka.sponest.event.centereventteventcatalogue.domain.CentereventTEventcatalogue;
import com.sooka.sponest.event.centereventteventcatalogue.domain.DaHuaEventBO;
import com.sooka.sponest.event.centereventteventcatalogue.domain.dahua.DaHuaFireEventVO;
import com.sooka.sponest.event.centereventteventcatalogue.domain.dahua.DaHuaOtherEventVO;
import com.sooka.sponest.event.centereventteventcatalogue.domain.dahua.PictureVO;
import com.sooka.sponest.event.centereventteventcatalogue.domain.haikang.EventsVo;
import com.sooka.sponest.event.centereventteventcatalogue.domain.haikang.HaiKangEventVo;
import com.sooka.sponest.event.centereventteventcatalogue.domain.sensor.SensorEventVo;
import com.sooka.sponest.event.centereventteventcatalogue.service.AlarmEventService;
import com.sooka.sponest.event.centereventteventcatalogue.service.ICentereventTEventcatalogueService;
import com.sooka.sponest.event.centereventteventtype.domain.CentereventTEventtype;
import com.sooka.sponest.event.centereventteventtype.service.ICentereventTEventtypeService;
import com.sooka.sponest.event.centereventtfirelog.domain.CentereventTFireLog;
import com.sooka.sponest.event.centereventtfirelog.service.ICentereventTFireLogService;
import com.sooka.sponest.event.remoteapi.RemoteDataService;
import com.sooka.sponest.event.remoteapi.domain.CenterdataTAttach;
import com.sooka.sponest.event.utils.RemoteApiUtil;
import com.sooka.sponest.exchange.api.domain.FireEventVO;
import com.sooka.sponest.monitor.api.RemoteMonitorService;
import com.sooka.sponest.monitor.api.domain.CenterdataTAidevicedept;
import com.sooka.sponest.monitor.api.domain.CenterdataTCamera;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import static com.ruoyi.common.core.utils.DateUtils.YYYY_MM_DD_HH_MM_SS;
import static com.sooka.sponest.event.utils.EventConstants.*;

@Service
public class AlarmEventServiceImpl implements AlarmEventService {

    Logger logger = LoggerFactory.getLogger(AlarmEventServiceImpl.class);

    @Autowired
    private RemoteDataService remoteDataService;

    @Autowired
    private ICentereventTEventcatalogueService centereventTEventcatalogueService;

    @Autowired
    private ICentereventDeptEventService centereventTDeptEventService;

    @Autowired
    private ICentereventTFireLogService centereventTFireLogService;

    @Autowired
    private ICentereventTEventtypeService centereventTEventtypeService;

    @Value("${sooka.dahuaservice.detail}")
    private String detailUrl;

    static final String ERROR_MSG_CHANNEL = "无法匹配相关设备！通道编号为：{}";

    static final String ERROR_MSG_DEPT = "无法匹配相关部门！摄像头编号为：{}";

    @Transactional
    @Override
    public String insertHaiKangFireEvent(EventsVo eventsVo) {
        // 验证是否配置摄像头通道
        CenterdataTCamera centerdataTCamera = SpringUtils.getBean(RemoteMonitorService.class).getInfoByChannelCode(eventsVo.getSrcIndex()).getData();
        if (StringUtils.isNull(centerdataTCamera)) {
            logger.info(ERROR_MSG_CHANNEL, eventsVo.getSrcIndex());
            return "";
        }
        // 验证是否配置指挥中心
        List<CenterdataTAidevicedept> listDept = SpringUtils.getBean(RemoteMonitorService.class).listForCommandCenter(centerdataTCamera.getId(), "1", "1").getData();
        if (StringUtils.isEmpty(listDept)) {
            logger.info(ERROR_MSG_DEPT, centerdataTCamera.getCameraCode());
            return "";
        }
        // 事件目录
        String eventName = eventsVo.getData().getAlarm().getEventName();
        String eventDescription = eventsVo.getData().getAlarm().toString();
        String longitude = eventsVo.getData().getAlarm().getLongitude();
        String latitude = eventsVo.getData().getAlarm().getLatitude();
        String reportor = eventsVo.getSrcName();
        Date reportTime = eventsVo.getData().getSendTime();
        String address = eventsVo.getData().getAlarm().getPlaceName();
        CentereventTEventcatalogue centereventTEventcatalogue = new CentereventTEventcatalogue("1", null, eventName, eventDescription, longitude, latitude, reportor, reportTime, address,
                REPORTING_SOURCE_1, "上报", FOREST_EVENT_STATUS_1, centerdataTCamera.getId(), centerdataTCamera.getCameraName(), DateUtils.getNowDate());
        this.insertEventCatalogue(centereventTEventcatalogue);
        // 事件部门
        this.insertEventDept(centereventTEventcatalogue, listDept);
        // 事件日志
        String logId = this.insertEventLog(centereventTEventcatalogue);
        // 附件
        if (StringUtils.isNotBlank(eventsVo.getData().getImageUrl())) {
            CenterdataTAttach tAttach = new CenterdataTAttach();
            tAttach.setBusId(logId);
            tAttach.setAttachPath(eventsVo.getData().getImageUrl());
            tAttach.setBusIndx(BUS_INDEX_1);
            tAttach.setBusSource("HIK_1");
            tAttach.setFileType(FILE_TYPE_1);
            remoteDataService.insertAttach(tAttach);
        }
        if (StringUtils.isNotBlank(eventsVo.getData().getVisiblePicUrl())) {
            CenterdataTAttach tAttach = new CenterdataTAttach();
            tAttach.setBusId(logId);
            tAttach.setAttachPath(eventsVo.getData().getVisiblePicUrl());
            tAttach.setBusIndx(BUS_INDEX_1);
            tAttach.setBusSource("HIK_1");
            tAttach.setFileType(FILE_TYPE_1);
            remoteDataService.insertAttach(tAttach);
        }
        return centereventTEventcatalogue.getEventCode();
    }

    @Transactional
    @Override
    public String insertHaiKangCityEvent(HaiKangEventVo haiKangEventVo) {
        EventsVo eventsVo = haiKangEventVo.getEvents()[0];
        // 验证是否配置摄像头通道
        CenterdataTCamera centerdataTCamera = SpringUtils.getBean(RemoteMonitorService.class).getInfoByChannelCode(eventsVo.getSrcIndex()).getData();
        if (StringUtils.isNull(centerdataTCamera)) {
            logger.info(ERROR_MSG_CHANNEL, eventsVo.getSrcIndex());
            return "";
        }
        // 验证是否配置指挥中心
        List<CenterdataTAidevicedept> listDept = SpringUtils.getBean(RemoteMonitorService.class).listForCommandCenter(centerdataTCamera.getId(), "1", "1").getData();
        if (StringUtils.isEmpty(listDept)) {
            logger.info(ERROR_MSG_DEPT, centerdataTCamera.getCameraCode());
            return "";
        }
        // 验证事件类型是否配置对应报文码值--只能从数据库配
        CentereventTEventtype centereventTEventtype = centereventTEventtypeService.selectCentereventTEventtypeByCode(haiKangEventVo.getEvents()[0].getData().getText()[0].getAlarmType());
        if (StringUtils.isNull(centereventTEventtype)) {
            logger.info("无法匹配相关事件！报文码值为：{}", haiKangEventVo.getEvents()[0].getData().getText()[0].getAlarmType());
            return "";
        }
        // 事件目录
        String eventType = centereventTEventtype.getParentId();
        String eventTypeXl = centereventTEventtype.getId();
        String eventName = centerdataTCamera.getCameraName() + haiKangEventVo.getSendTime() + eventsVo.getData().getText()[0].getAlarmTypeName();
        String eventDescription = eventsVo.toString(centerdataTCamera);
        String longitude = centerdataTCamera.getLongitude();
        String latitude = centerdataTCamera.getLatitude();
        String reportor = eventsVo.getSrcName();
        Date reportTime = haiKangEventVo.getSendTime();
        String address = eventsVo.getData().getText()[0].getOrgName();
        CentereventTEventcatalogue centereventTEventcatalogue = new CentereventTEventcatalogue(eventType, eventTypeXl, eventName, eventDescription, longitude, latitude, reportor, reportTime, address,
                REPORTING_SOURCE_1, "上报", FOREST_EVENT_STATUS_1, centerdataTCamera.getId(), centerdataTCamera.getCameraName(), DateUtils.getNowDate());
        this.insertEventCatalogue(centereventTEventcatalogue);
        // 事件部门
        this.insertEventDept(centereventTEventcatalogue, listDept);
        // 事件日志
        String logId = this.insertEventLog(centereventTEventcatalogue);
        if (StringUtils.isNotBlank(eventsVo.getData().getText()[0].getAlarmPicUrl())) {
            CenterdataTAttach tAttach = new CenterdataTAttach();
            tAttach.setBusId(logId);
            tAttach.setAttachPath(eventsVo.getData().getText()[0].getAlarmPicUrl());
            tAttach.setBusIndx("bus_indx_city");
            tAttach.setBusSource("HIK_2");
            tAttach.setFileType(FILE_TYPE_1);
            remoteDataService.insertAttach(tAttach);
        }
        return centereventTEventcatalogue.getEventCode();
    }

    // 事件目录
    private void insertEventCatalogue(CentereventTEventcatalogue eventcatalogue) {
        //生成uuid
        String eventCode = IdUtils.simpleUUID();
        eventcatalogue.setId(eventCode);
        eventcatalogue.setEventCode(eventCode);
        eventcatalogue.setIsUrged(SYS_ISURGE_2);// sys_isurge_2
        eventcatalogue.setEventStatus(null == eventcatalogue.getEventStatus() ? "上报" : eventcatalogue.getEventStatus());
        eventcatalogue.setEventStatusValue(null == eventcatalogue.getEventStatusValue() ? FOREST_EVENT_STATUS_1 : eventcatalogue.getEventStatusValue());// forest_event_status_1
        if (null == eventcatalogue.getCreateTime()) {
            eventcatalogue.setCreateTime(DateUtils.getNowDate());
        }
        centereventTEventcatalogueService.insertCentereventTEventcatalogue(eventcatalogue);
    }

    // 事件部门
    private void insertEventDept(CentereventTEventcatalogue eventcatalogue, List<CenterdataTAidevicedept> listDept) {
        listDept.forEach(item -> {
            CentereventDeptEvent deptEvent = new CentereventDeptEvent();
            deptEvent.setId(IdUtils.fastSimpleUUID());
            deptEvent.setEventCode(eventcatalogue.getEventCode());
            deptEvent.setDeptId(item.getMapDeptId());
            deptEvent.setDeptName(item.getMapDeptName());
            deptEvent.setIsUrged(SYS_ISURGE_2);
            deptEvent.setEventStatus(eventcatalogue.getEventStatus());
            deptEvent.setEventStatusValue(eventcatalogue.getEventStatusValue());
            if (REPORTING_SOURCE_5.equals(eventcatalogue.getReportSource())) {
                deptEvent.setDeptHandleType(DEPT_HANDLE_TYPE_1);
                deptEvent.setCreateBy(eventcatalogue.getCreateBy());
            } else {
                deptEvent.setDeptHandleType(DEPT_HANDLE_TYPE_2);
            }
            deptEvent.setCreateName(eventcatalogue.getCreateName());
            deptEvent.setCreateTime(eventcatalogue.getCreateTime());
            centereventTDeptEventService.insertCentereventTDeptEvent(deptEvent);
        });
    }

    // 事件日志
    private String insertEventLog(CentereventTEventcatalogue eventcatalogue) {
        CentereventTFireLog fireLog = new CentereventTFireLog();
        fireLog.setId(IdUtils.simpleUUID());
        fireLog.setEventCode(eventcatalogue.getEventCode());
        fireLog.setLogContent(eventcatalogue.getEventName() + System.getProperty("line.separator") + eventcatalogue.getEventDescription());
        fireLog.setOperation(BUS_OPER_TYPE_2);
        if (REPORTING_SOURCE_5.equals(eventcatalogue.getReportSource())) {
            fireLog.setOperationType(LOG_OPER_TYPE_4);
            fireLog.setCreateBy(eventcatalogue.getCreateBy());
        } else {
            fireLog.setOperationType(LOG_OPER_TYPE_3);
        }
        fireLog.setCreateName(eventcatalogue.getCreateName());
        fireLog.setCreateTime(eventcatalogue.getCreateTime());
        centereventTFireLogService.insertCentereventTFireLog(fireLog);
        return fireLog.getId();
    }


    @Transactional
    @Override
    public String insertDaHuaEvent(DaHuaFireEventVO daHuaFireEventVO) {
        Long type = daHuaFireEventVO.getInfo().getAlarmType();
        // 313：烟雾，5122：热感
        if (type == 313 || type == 5122) {
            return insertFireEvent(daHuaFireEventVO);
        }
        return "";
    }

    public String insertFireEvent(DaHuaFireEventVO daHuaFireEventVO) {
        // 验证是否配置摄像头通道
        CenterdataTCamera centerdataTCamera = SpringUtils.getBean(RemoteMonitorService.class).getInfoByChannelCode(daHuaFireEventVO.getInfo().getChannelSn()).getData();
        if (StringUtils.isNull(centerdataTCamera)) {
            logger.info(ERROR_MSG_CHANNEL, daHuaFireEventVO.getInfo().getChannelSn());
            return "";
        }
        // 验证是否配置指挥中心
        List<CenterdataTAidevicedept> listDept = SpringUtils.getBean(RemoteMonitorService.class).listForCommandCenter(centerdataTCamera.getId(), "1", "1").getData();
        if (StringUtils.isEmpty(listDept)) {
            logger.info(ERROR_MSG_DEPT, centerdataTCamera.getCameraCode());
            return "";
        }
        // 事件目录
        //四平市双辽市卧虎镇贺家村热感应 + 2024-01-05 10:32:54 + 火情报警
        String eventName = daHuaFireEventVO.getInfo().getChannelName() + daHuaFireEventVO.getInfo().getAlarmDateStr() + daHuaFireEventVO.getInfo().getAlarmTypeName();
        String eventDescription = daHuaFireEventVO.getInfo().toString(centerdataTCamera);
        String longitude = StringUtils.isEmpty(daHuaFireEventVO.getInfo().getFirePoint()) ? centerdataTCamera.getLongitude() : daHuaFireEventVO.getInfo().getFirePoint()[0].getGpsX();
        String latitude = StringUtils.isEmpty(daHuaFireEventVO.getInfo().getFirePoint()) ? centerdataTCamera.getLatitude() : daHuaFireEventVO.getInfo().getFirePoint()[0].getGpsY();
        String reportor = daHuaFireEventVO.getInfo().getDeviceName();
        Date reportTime = DateUtils.timestampToTime(daHuaFireEventVO.getInfo().getAlarmDate());
        String address = centerdataTCamera.getCameraRegion();
        CentereventTEventcatalogue centereventTEventcatalogue = new CentereventTEventcatalogue("1", null, eventName, eventDescription, longitude, latitude, reportor, reportTime, address,
                REPORTING_SOURCE_1, "上报", FOREST_EVENT_STATUS_1, centerdataTCamera.getId(), centerdataTCamera.getCameraName(), daHuaFireEventVO.getCreateTime());
        this.insertEventCatalogue(centereventTEventcatalogue);
        // 事件部门
        this.insertEventDept(centereventTEventcatalogue, listDept);
        // 事件日志
        String logId = this.insertEventLog(centereventTEventcatalogue);
        if (StringUtils.isNotBlank(daHuaFireEventVO.getInfo().getPicture())) {
            String[] pictures = daHuaFireEventVO.getInfo().getPicture().split(",");
            for (String picture : pictures) {
                CenterdataTAttach tAttach = new CenterdataTAttach();
                tAttach.setBusId(logId);
                tAttach.setAttachPath(picture);
                tAttach.setBusIndx(BUS_INDEX_1);
                tAttach.setBusSource("DH_1");
                tAttach.setFileType(FILE_TYPE_1);
                remoteDataService.insertAttach(tAttach);
            }
        }
        return centereventTEventcatalogue.getEventCode();
    }

    @Override
    public String updateFireEventImage(DaHuaEventBO eventBO) throws ClientException {
        // 通过eventCode查询详情
        CentereventTEventcatalogue centereventTEventcatalogue = centereventTEventcatalogueService.selectCentereventTEventcatalogueById(eventBO.getEventCode());
        // 确认为   火情事件   并且   状态为上报
        if ("1".equals(centereventTEventcatalogue.getEventType()) && "forest_event_status_1".equals(centereventTEventcatalogue.getEventStatusValue())) {
            // 按照指定格式拼接路径
            String url = "alarmCode=" + RemoteApiUtil.encodeUrl(eventBO.getAlarmCode()) + "&dbType=" + RemoteApiUtil.encodeUrl(eventBO.getDbType()) + "&alarmDate=" + RemoteApiUtil.encodeUrl(eventBO.getAlarmDate());
            // 创建请求实体 并 发送请求
            String prBody = new IccHttpHttpRequest(detailUrl + url)
                    // 设置token
                    .header("Authorization", "bearer " + RemoteApiUtil.getInstance().getToken())
                    // 客户端模式，设置请求头 # clientKey & clientValue 在请求大华接口时，以客户端模式请求必填。客户端模式无法请求：考勤，客流，信息发布，报警主机等模块
                    .header("User-Id", "1")
                    // 发送请求
                    .execute();
            // 处理响应结果
            JSONObject responseData = JSON.parseObject(prBody);
            if (responseData.getBoolean("success")) {
                ArrayList<String> pictures = responseData.getJSONObject("data").getObject("pictures", ArrayList.class);
                if (pictures.isEmpty()) {
                    logger.error("获取的图片集合为空-----请求结果：{}", prBody);
                    return "暂无图片, 请稍后重试";
                }
                // 添加新附件
                List<CenterdataTAttach> attachList = new ArrayList<>();
                for (String picture : pictures) {
                    CenterdataTAttach tAttach = new CenterdataTAttach();
                    tAttach.setBusId(eventBO.getLogId());
                    tAttach.setAttachPath(picture);
                    tAttach.setBusIndx(BUS_INDEX_1);
                    tAttach.setBusSource("DH_1");
                    tAttach.setFileType(FILE_TYPE_1);
                    attachList.add(tAttach);
                }
                return remoteDataService.delAndInsertBatch(JSON.toJSONString(attachList)).getMsg();
            }
            logger.error("请求远端异常-----请求结果：{}", prBody);
            return "请求异常, 请联系管理员";
        }
        return "请刷新后重试";
    }

    @Override
    public String insertDaHuaOtherEvent(DaHuaOtherEventVO daHuaOtherEventVO) {
        // 验证是否配置摄像头通道
        CenterdataTCamera centerdataTCamera = SpringUtils.getBean(RemoteMonitorService.class).getInfoByChannelCode(daHuaOtherEventVO.getChannelSn()).getData();
        if (StringUtils.isNull(centerdataTCamera)) {
            logger.info(ERROR_MSG_CHANNEL, daHuaOtherEventVO.getChannelSn());
            return "";
        }
        // 验证是否配置指挥中心
        List<CenterdataTAidevicedept> listDept = SpringUtils.getBean(RemoteMonitorService.class).listForCommandCenter(centerdataTCamera.getId(), "1", "1").getData();
        if (StringUtils.isEmpty(listDept)) {
            logger.info(ERROR_MSG_DEPT, centerdataTCamera.getCameraCode());
            return "";
        }
        // 验证事件类型是否配置对应报文码值--只能从数据库配
        CentereventTEventtype centereventTEventtype = centereventTEventtypeService.selectCentereventTEventtypeByCode(daHuaOtherEventVO.getAlarmType());
        if (StringUtils.isNull(centereventTEventtype)) {
            logger.info("无法匹配相关事件！报文码值为：{}", daHuaOtherEventVO.getAlarmType());
            return "";
        }
        // 事件目录
        String eventType = centereventTEventtype.getParentId();
        String eventTypeXl = centereventTEventtype.getId();
        String eventName = centerdataTCamera.getCameraName() + DateUtils.parseDateToStr(YYYY_MM_DD_HH_MM_SS, DateUtils.timestampToTime(daHuaOtherEventVO.getOccurrenceTime())) + daHuaOtherEventVO.getAlarmName();
        String eventDescription = daHuaOtherEventVO.toString();
        String longitude = daHuaOtherEventVO.getLongitude();
        String latitude = daHuaOtherEventVO.getLatitude();
        String reportor = centerdataTCamera.getCameraName();
        Date reportTime = DateUtils.timestampToTime(daHuaOtherEventVO.getOccurrenceTime());
        String address = daHuaOtherEventVO.getAddress();
        CentereventTEventcatalogue centereventTEventcatalogue = new CentereventTEventcatalogue(eventType, eventTypeXl, eventName, eventDescription, longitude, latitude, reportor, reportTime, address,
                REPORTING_SOURCE_1, "上报", FOREST_EVENT_STATUS_1, centerdataTCamera.getId(), centerdataTCamera.getCameraName(), daHuaOtherEventVO.getCreateTime());
        this.insertEventCatalogue(centereventTEventcatalogue);
        // 事件部门
        this.insertEventDept(centereventTEventcatalogue, listDept);
        // 事件日志
        String logId = this.insertEventLog(centereventTEventcatalogue);
        if (StringUtils.isNotBlank(daHuaOtherEventVO.getImgList())) {
            List<PictureVO> pictures = JSON.parseArray(daHuaOtherEventVO.getImgList(), PictureVO.class);
            for (PictureVO picture : pictures) {
                CenterdataTAttach tAttach = new CenterdataTAttach();
                tAttach.setBusId(logId);
                tAttach.setAttachPath(picture.getImgUrl().substring(picture.getImgUrl().indexOf("/image")));
                tAttach.setBusIndx(BUS_INDEX_2);
                tAttach.setBusSource("DH_2");
                tAttach.setFileType(FILE_TYPE_1);
                remoteDataService.insertAttach(tAttach);
            }
        }
        return centereventTEventcatalogue.getEventCode();
    }

    @Transactional
    @Override
    public String insertSensorEvent(SensorEventVo sensorEventVo) {
        // 验证是否配置指挥中心
        List<CenterdataTAidevicedept> listDept = SpringUtils.getBean(RemoteMonitorService.class).listForCommandCenter(sensorEventVo.getSensorId(), "1", "1").getData();
        if (StringUtils.isEmpty(listDept)) {
            logger.info(ERROR_MSG_DEPT, sensorEventVo.getReportor());
            return "";
        }
        // 事件目录
        CentereventTEventtype eventtype = centereventTEventtypeService.selectCentereventTEventtypeById(sensorEventVo.getEventTypeXl());
        String eventName = sensorEventVo.getReportor() + DateUtils.parseDateToStr(YYYY_MM_DD_HH_MM_SS, sensorEventVo.getReportTime()) + eventtype.getEventTypeName();
        CentereventTEventcatalogue centereventTEventcatalogue = new CentereventTEventcatalogue(sensorEventVo.getEventType(), sensorEventVo.getEventTypeXl(), eventName, sensorEventVo.getEventDescription(), sensorEventVo.getLongitude(), sensorEventVo.getLatitude(), sensorEventVo.getReportor(), sensorEventVo.getReportTime(), sensorEventVo.getAddress(),
                REPORTING_SOURCE_4, "上报", FOREST_EVENT_STATUS_1, sensorEventVo.getSensorId(), sensorEventVo.getReportor(), DateUtils.getNowDate());
        this.insertEventCatalogue(centereventTEventcatalogue);
        // 事件部门
        this.insertEventDept(centereventTEventcatalogue, listDept);
        // 事件日志
        String logId = this.insertEventLog(centereventTEventcatalogue);
        if (StringUtils.isNotBlank(sensorEventVo.getPicture())) {
            CenterdataTAttach tAttach = new CenterdataTAttach();
            tAttach.setBusId(logId);
            tAttach.setAttachPath(sensorEventVo.getPicture());
            tAttach.setBusIndx(BUS_INDEX_3);
            tAttach.setBusSource("SENSOR");
            tAttach.setFileType(FILE_TYPE_1);
            remoteDataService.insertAttach(tAttach);
        }
        return centereventTEventcatalogue.getEventCode() + "_" + eventtype.getEventTypeName();
    }

    /**
     * 119平台上报事件
     *
     * @param fireEventVO
     * @return
     */
    @Override
    public String insert3rdSystemEvent(FireEventVO fireEventVO) {
        // 事件信息
        CentereventTEventcatalogue eventcatalogue = new CentereventTEventcatalogue(fireEventVO.getEventSupType(), fireEventVO.getEventType(), fireEventVO.getEventName(), fireEventVO.getEventDescription(),
                fireEventVO.getEventLongitude(), fireEventVO.getEventLatitude(), fireEventVO.getEventReporter(), fireEventVO.getEventReportTime(), fireEventVO.getEventLocation(), REPORTING_SOURCE_5,
                "签收", FOREST_EVENT_STATUS_2, SecurityUtils.getLoginUser().getSysUser().getUserId().toString(), SecurityUtils.getLoginUser().getSysUser().getNickName(), DateUtils.getNowDate());
        eventcatalogue.setDeptId(SecurityUtils.getLoginUser().getSysUser().getDeptId());
        eventcatalogue.setDeptName(SecurityUtils.getLoginUser().getSysUser().getDeptNames());
        this.insertEventCatalogue(eventcatalogue);
        // 事件部门
        List<CenterdataTAidevicedept> listDept = new ArrayList<>();
        listDept.add(new CenterdataTAidevicedept(eventcatalogue.getDeptId(), eventcatalogue.getDeptName()));
        this.insertEventDept(eventcatalogue, listDept);
        String logId = this.insertEventLog(eventcatalogue);
        List<CenterdataTAttach> attachList = new ArrayList<>();
        for (String picture : fireEventVO.getPictureUrlList()) {
            CenterdataTAttach attach = new CenterdataTAttach();
            attach.setBusId(logId);
            attach.setAttachPath(picture);
            attach.setBusIndx(BUS_INDEX_1);
            attach.setBusSource("3RD");
            attach.setFileType(FILE_TYPE_1);
            attachList.add(attach);
        }
        remoteDataService.delAndInsertBatch(JSON.toJSONString(attachList));
        return eventcatalogue.getEventCode();
    }
}
