package com.sooka.sponest.event.emergency.danger.controller;

import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.utils.file.FilePrefixUtils;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.common.security.utils.SecurityUtils;
import com.sooka.sponest.event.emergency.danger.domain.CentereventTEmergencyDanger;
import com.sooka.sponest.event.emergency.danger.service.ICentereventTEmergencyDangerService;
import com.sooka.sponest.event.emergency.dangerdeptmap.domain.CentereventTEmergencyDangerdeptmap;
import com.sooka.sponest.event.emergency.dangerdeptmap.service.ICentereventTEmergencyDangerdeptmapService;
import com.sooka.sponest.event.emergency.dangerprocess.domain.CentereventTEmergencyDangerprocess;
import com.sooka.sponest.event.emergency.dangerprocess.service.ICentereventTEmergencyDangerprocessService;
import com.sooka.sponest.event.emergency.patrolrecord.domain.CentereventTEmergencyPatrolrecord;
import com.sooka.sponest.event.emergency.patrolrecord.service.ICentereventTEmergencyPatrolrecordService;
import com.sooka.sponest.event.remoteapi.RemoteDataService;
import com.sooka.sponest.event.remoteapi.domain.CenterdataTAttach;
import com.sooka.sponest.event.utils.ExcelUtil;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 安全隐患Controller
 *
 * @author ruoyi
 * @date 2022-07-20
 */
@RestController
@RequestMapping("/danger")
public class CentereventTEmergencyDangerController extends BaseController {

    @Autowired
    private ICentereventTEmergencyDangerService centereventTEmergencyDangerService;

    @Autowired
    private ICentereventTEmergencyDangerdeptmapService centereventTEmergencyDangerdeptmapService;

    @Autowired
    private ICentereventTEmergencyDangerprocessService centereventTEmergencyDangerprocessService;

    @Autowired
    private RemoteDataService remoteDataService;

    @Autowired
    private ICentereventTEmergencyPatrolrecordService centereventTEmergencyPatrolrecordService;

    /**
     * 查询安全隐患列表
     */
    @RequiresPermissions("danger:danger:list")
    @GetMapping("/list")
    public TableDataInfo list(CentereventTEmergencyDanger centereventTEmergencyDanger) {
        startPage();
        List<CentereventTEmergencyDanger> list = centereventTEmergencyDangerService.selectCentereventTEmergencyDangerList(centereventTEmergencyDanger);
        return getDataTable(list);
    }

    @ApiOperation("查询安全隐患列表")
    @GetMapping("/getAllDanger")
    public R<List<CentereventTEmergencyDanger>> getAllDanger(CentereventTEmergencyDanger centereventTEmergencyDanger) {
        return R.ok(centereventTEmergencyDangerService.selectCentereventTEmergencyDangerList(centereventTEmergencyDanger));
    }

    /**
     * 导出安全隐患列表
     */
    @RequiresPermissions("danger:danger:export")
    @Log(title = "安全隐患", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CentereventTEmergencyDanger centereventTEmergencyDanger) {
        List<CentereventTEmergencyDanger> list = centereventTEmergencyDangerService.selectCentereventTEmergencyDangerList(centereventTEmergencyDanger);
        ExcelUtil<CentereventTEmergencyDanger> util = new ExcelUtil<>(CentereventTEmergencyDanger.class);
        util.exportExcel(response, list, "安全隐患数据");
    }

    /**
     * 获取安全隐患详细信息
     */
//    @RequiresPermissions("danger:danger:query")
    @ApiOperation("获取安全隐患详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id) {
        return AjaxResult.success(centereventTEmergencyDangerService.selectCentereventTEmergencyDangerById(id));
    }

    @ApiOperation("获取安全隐患、隐患处理过程详细信息")
    @GetMapping(value = "/getInfoView/{id}")
    public AjaxResult getInfoView(@PathVariable("id") String id) {
        Map<String, Object> resultMap = new HashMap<>();
        resultMap.put("danger", centereventTEmergencyDangerService.selectCentereventTEmergencyDangerById(id));
        resultMap.put("process", centereventTEmergencyDangerprocessService.selectCentereventTEmergencyDangerprocessList(new CentereventTEmergencyDangerprocess(id)));
        return AjaxResult.success(resultMap);
    }

    /**
     * 新增安全隐患
     */
//    @RequiresPermissions("danger:danger:add")
    @ApiOperation("新增安全隐患")
    @Log(title = "安全隐患", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@Validated @RequestBody CentereventTEmergencyDanger centereventTEmergencyDanger) {
        int result = centereventTEmergencyDangerService.insertCentereventTEmergencyDanger(centereventTEmergencyDanger);
        if (result > 0) {
            // 责任部门
            CentereventTEmergencyDangerdeptmap centereventTEmergencyDangerdeptmap = new CentereventTEmergencyDangerdeptmap();
            centereventTEmergencyDangerdeptmap.setDangerId(centereventTEmergencyDanger.getId());
            centereventTEmergencyDangerdeptmap.setHandleStatus("dept_handleType_1");
            centereventTEmergencyDangerdeptmap.setDeptId(centereventTEmergencyDanger.getDeptId());
            centereventTEmergencyDangerdeptmap.setDeptName(centereventTEmergencyDanger.getDeptName());
            centereventTEmergencyDangerdeptmapService.insertCentereventTEmergencyDangerdeptmap(centereventTEmergencyDangerdeptmap);
            // 联动部门
            centereventTEmergencyDanger.getDepts().forEach(item -> {
                item.setDangerId(centereventTEmergencyDanger.getId());
                item.setHandleStatus("dept_handleType_2");
                centereventTEmergencyDangerdeptmapService.insertCentereventTEmergencyDangerdeptmap(item);
            });
            // 日志
            centereventTEmergencyDanger.setDangerStatusLabel("整改中");
            centereventTEmergencyDangerprocessService.insertCentereventTEmergencyDangerprocess(centereventTEmergencyDanger);
            // 附件
            centereventTEmergencyDanger.getAttachs().forEach(item -> {
                CenterdataTAttach attach = new CenterdataTAttach();
                attach.setBusId(centereventTEmergencyDanger.getId());
                attach.setAttachPath(item.getAttachPath());
                attach.setBusIndx("bus_indx_danger");
                attach.setBusSource("APP");
                attach.setFileName(item.getFileName());
                attach.setFileType(FilePrefixUtils.getUrlSuffix(item.getAttachPath()));
                remoteDataService.insertAttach(attach);
            });
            // 巡检反绑隐患id
            CentereventTEmergencyPatrolrecord centereventTEmergencyPatrolrecord = new CentereventTEmergencyPatrolrecord();
            centereventTEmergencyPatrolrecord.setId(centereventTEmergencyDanger.getDangerStatusLabel());// 新增时label字段传入的是巡检id
            centereventTEmergencyPatrolrecord.setIsHavedanger("1");// 0否1是
            centereventTEmergencyPatrolrecord.setDangerId(centereventTEmergencyDanger.getId());
            centereventTEmergencyPatrolrecordService.updateCentereventTEmergencyPatrolrecord(centereventTEmergencyPatrolrecord);
        }
        return toAjax(result);
    }

    /**
     * 修改安全隐患
     */
//    @RequiresPermissions("danger:danger:edit")
    @ApiOperation("修改安全隐患流程")
    @Log(title = "安全隐患", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CentereventTEmergencyDanger centereventTEmergencyDanger) {
        String userId = SecurityUtils.getUserId().toString();
        CentereventTEmergencyDanger danger = centereventTEmergencyDangerService.selectCentereventTEmergencyDangerById(centereventTEmergencyDanger.getId());
        if (!userId.equals(danger.getCreateBy())) {
            return AjaxResult.error("无更改权限");
        }
        danger.setDangerStatus(centereventTEmergencyDanger.getDangerStatus());
        danger.setDangerStatusLabel(centereventTEmergencyDanger.getDangerStatusLabel());
        int result = centereventTEmergencyDangerService.updateCentereventTEmergencyDanger(danger);
        if (result > 0) {
            // 日志
            danger.setDangerContent(centereventTEmergencyDanger.getDangerContent());
            centereventTEmergencyDangerprocessService.insertCentereventTEmergencyDangerprocess(danger);
        }
        return toAjax(result);
    }

    /**
     * 删除安全隐患
     */
    @RequiresPermissions("danger:danger:remove")
    @Log(title = "安全隐患", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids) {
        return toAjax(centereventTEmergencyDangerService.deleteCentereventTEmergencyDangerByIds(ids));
    }

    @ApiOperation("查询当月每日隐患数量")
    @PostMapping("/selectDangerByCalendar")
    public R selectDangerByCalendar(@RequestBody CentereventTEmergencyDanger centereventTEmergencyDanger) {
        return R.ok(centereventTEmergencyDangerService.selectDangerByCalendar(centereventTEmergencyDanger));
    }

    @GetMapping("/selectStatsMap")
    public AjaxResult selectStatsMap() {
        return AjaxResult.success(centereventTEmergencyDangerService.selectStatsMap());
    }
}
