package com.sooka.sponest.event.emergency.danger.service.impl;

import com.ruoyi.common.core.utils.DateUtils;
import com.ruoyi.common.core.utils.SpringUtils;
import com.ruoyi.common.core.utils.StringUtils;
import com.ruoyi.common.core.utils.uuid.IdUtils;
import com.ruoyi.common.datascope.annotation.DataScopeMutiDept;
import com.ruoyi.common.datascope.base.service.BaseService;
import com.ruoyi.common.security.utils.SecurityUtils;
import com.ruoyi.system.api.RemoteConfigService;
import com.sooka.sponest.event.emergency.danger.domain.CentereventTEmergencyDanger;
import com.sooka.sponest.event.emergency.danger.mapper.CentereventTEmergencyDangerMapper;
import com.sooka.sponest.event.emergency.danger.service.ICentereventTEmergencyDangerService;
import com.sooka.sponest.event.remoteapi.RemoteDataService;
import com.sooka.sponest.event.remoteapi.domain.CenterdataTAttach;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;

import static com.sooka.sponest.event.utils.EventConstants.FILE_PREFIX_LOCAL;

/**
 * 安全隐患Service业务层处理
 *
 * @author ruoyi
 * @date 2022-07-20
 */
@Service
public class CentereventTEmergencyDangerServiceImpl extends BaseService implements ICentereventTEmergencyDangerService {

    @Autowired
    private CentereventTEmergencyDangerMapper centereventTEmergencyDangerMapper;

    @Autowired
    private RemoteDataService remoteDataService;

    /**
     * 查询安全隐患列表
     *
     * @param centereventTEmergencyDanger 安全隐患
     * @return 安全隐患
     */
    @DataScopeMutiDept(deptAlias = "d")
    @Override
    public List<CentereventTEmergencyDanger> selectCentereventTEmergencyDangerList(CentereventTEmergencyDanger centereventTEmergencyDanger) {
        setSookaDataBase(centereventTEmergencyDanger);
        return centereventTEmergencyDangerMapper.selectCentereventTEmergencyDangerList(centereventTEmergencyDanger);
    }

    /**
     * 查询安全隐患
     *
     * @param id 安全隐患主键
     * @return 安全隐患
     */
    @Override
    public CentereventTEmergencyDanger selectCentereventTEmergencyDangerById(String id) {
        CentereventTEmergencyDanger centereventTEmergencyDanger = centereventTEmergencyDangerMapper.selectCentereventTEmergencyDangerById(id);
        CenterdataTAttach centerdataTAttach = new CenterdataTAttach();
        centerdataTAttach.setBusId(centereventTEmergencyDanger.getId());
        List<CenterdataTAttach> attachs = remoteDataService.remoteattachlist(centerdataTAttach).getData();
        if (StringUtils.isNotEmpty(attachs)) {
            String prefix = SpringUtils.getBean(RemoteConfigService.class).remotegetConfigKey(FILE_PREFIX_LOCAL).getData();
            attachs.forEach(item -> item.setAttachPath(prefix + item.getAttachPath()));
        }
        centereventTEmergencyDanger.setAttachs(attachs);
        return centereventTEmergencyDanger;
    }

    /**
     * 新增安全隐患
     *
     * @param centereventTEmergencyDanger 安全隐患
     * @return 结果
     */
    @Override
    public int insertCentereventTEmergencyDanger(CentereventTEmergencyDanger centereventTEmergencyDanger) {
        centereventTEmergencyDanger.setId(IdUtils.fastSimpleUUID());
        centereventTEmergencyDanger.setCreateBy(SecurityUtils.getUserId().toString());
        centereventTEmergencyDanger.setCreateTime(DateUtils.getNowDate());
        centereventTEmergencyDanger.setDangerStatus("trouble_status_2");// 整改中
        centereventTEmergencyDanger.setDangerReport(SecurityUtils.getLoginUser().getSysUser().getNickName());
        return centereventTEmergencyDangerMapper.insertCentereventTEmergencyDanger(centereventTEmergencyDanger);
    }

    /**
     * 修改安全隐患
     *
     * @param centereventTEmergencyDanger 安全隐患
     * @return 结果
     */
    @Override
    public int updateCentereventTEmergencyDanger(CentereventTEmergencyDanger centereventTEmergencyDanger) {
        centereventTEmergencyDanger.setUpdateBy(SecurityUtils.getUserId());
        centereventTEmergencyDanger.setUpdateTime(DateUtils.getNowDate());
        return centereventTEmergencyDangerMapper.updateCentereventTEmergencyDanger(centereventTEmergencyDanger);
    }

    /**
     * 批量删除安全隐患
     *
     * @param ids 需要删除的安全隐患主键
     * @return 结果
     */
    @Override
    public int deleteCentereventTEmergencyDangerByIds(String[] ids) {
        return centereventTEmergencyDangerMapper.deleteCentereventTEmergencyDangerByIds(ids);
    }

    @DataScopeMutiDept(deptAlias = "d")
    @Override
    public List<Map<String, Object>> selectDangerByCalendar(CentereventTEmergencyDanger centereventTEmergencyDanger) {
        setSookaDataBase(centereventTEmergencyDanger);
        return centereventTEmergencyDangerMapper.selectDangerByCalendar(centereventTEmergencyDanger);
    }

    @Override
    public List<Map> selectStatsMap() {
        CentereventTEmergencyDanger centereventTEmergencyDanger = new CentereventTEmergencyDanger();
        setSookaDataBase(centereventTEmergencyDanger);
        return centereventTEmergencyDangerMapper.selectStatsMap(centereventTEmergencyDanger);
    }
}
