package com.sooka.sponest.event.emergency.dangerprocess.controller;

import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.sooka.sponest.event.emergency.danger.service.ICentereventTEmergencyDangerService;
import com.sooka.sponest.event.emergency.dangerprocess.domain.CentereventTEmergencyDangerprocess;
import com.sooka.sponest.event.emergency.dangerprocess.domain.DayBody;
import com.sooka.sponest.event.emergency.dangerprocess.service.ICentereventTEmergencyDangerprocessService;
import com.sooka.sponest.event.remoteapi.RemoteDataService;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 隐患处理过程Controller
 *
 * @author ruoyi
 * @date 2022-07-20
 */
@RestController
@RequestMapping("/dangerprocess")
public class CentereventTEmergencyDangerprocessController extends BaseController {

    @Autowired
    private ICentereventTEmergencyDangerprocessService centereventTEmergencyDangerprocessService;

    @Autowired
    private ICentereventTEmergencyDangerService centereventTEmergencyDangerService;

    @Autowired
    private RemoteDataService remoteDataService;

    /**
     * 查询隐患处理过程列表
     */
    @RequiresPermissions("dangerprocess:dangerprocess:list")
    @GetMapping("/list")
    public TableDataInfo list(CentereventTEmergencyDangerprocess centereventTEmergencyDangerprocess) {
        startPage();
        List<CentereventTEmergencyDangerprocess> list = centereventTEmergencyDangerprocessService.selectCentereventTEmergencyDangerprocessList(centereventTEmergencyDangerprocess);
        return getDataTable(list);
    }

    @GetMapping("/getAllDangerprocess")
    public R<List<CentereventTEmergencyDangerprocess>> getAllDangerprocess(CentereventTEmergencyDangerprocess centereventTEmergencyDangerprocess) {
        return R.ok(centereventTEmergencyDangerprocessService.selectCentereventTEmergencyDangerprocessList(centereventTEmergencyDangerprocess));
    }

    /**
     * 导出隐患处理过程列表
     */
    @RequiresPermissions("dangerprocess:dangerprocess:export")
    @Log(title = "隐患处理过程", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CentereventTEmergencyDangerprocess centereventTEmergencyDangerprocess) {
        List<CentereventTEmergencyDangerprocess> list = centereventTEmergencyDangerprocessService.selectCentereventTEmergencyDangerprocessList(centereventTEmergencyDangerprocess);
        ExcelUtil<CentereventTEmergencyDangerprocess> util = new ExcelUtil<>(CentereventTEmergencyDangerprocess.class);
        util.exportExcel(response, list, "隐患处理过程数据");
    }

    /**
     * 获取隐患处理过程详细信息
     */
    @RequiresPermissions("dangerprocess:dangerprocess:query")
    @GetMapping(value = "/{pkId}")
    public AjaxResult getInfo(@PathVariable("pkId") String pkId) {
        return AjaxResult.success(centereventTEmergencyDangerprocessService.selectCentereventTEmergencyDangerprocessByPkId(pkId));
    }

    /**
     * 新增隐患处理过程
     */
//    @RequiresPermissions("dangerprocess:dangerprocess:add")
    @ApiOperation("新增隐患处理过程")
    @Log(title = "隐患处理过程", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@Validated @RequestBody CentereventTEmergencyDangerprocess centereventTEmergencyDangerprocess) {
        String enterpriseId = centereventTEmergencyDangerService.selectCentereventTEmergencyDangerById(centereventTEmergencyDangerprocess.getDangerId()).getEnterpriseId();
        String telphone = remoteDataService.getEnterprise(enterpriseId).getData().getSecChargerPhone();
        centereventTEmergencyDangerprocess.setTelphone(telphone);
        return toAjax(centereventTEmergencyDangerprocessService.insertCentereventTEmergencyDangerprocess(centereventTEmergencyDangerprocess));
    }

    /**
     * 修改隐患处理过程
     */
    @RequiresPermissions("dangerprocess:dangerprocess:edit")
    @Log(title = "隐患处理过程", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CentereventTEmergencyDangerprocess centereventTEmergencyDangerprocess) {
        return toAjax(centereventTEmergencyDangerprocessService.updateCentereventTEmergencyDangerprocess(centereventTEmergencyDangerprocess));
    }

    /**
     * 删除隐患处理过程
     */
    @RequiresPermissions("dangerprocess:dangerprocess:remove")
    @Log(title = "隐患处理过程", businessType = BusinessType.DELETE)
    @DeleteMapping("/{pkIds}")
    public AjaxResult remove(@PathVariable String[] pkIds) {
        return toAjax(centereventTEmergencyDangerprocessService.deleteCentereventTEmergencyDangerprocessByPkIds(pkIds));
    }

    @GetMapping("/getHeatMap")
    public AjaxResult getHeatMap(DayBody dayBody) {
        return AjaxResult.success(centereventTEmergencyDangerprocessService.getHeatMap(dayBody));
    }
}
