package com.sooka.sponest.event.emergency.dangerprocess.service.impl;

import com.ruoyi.common.core.utils.DateUtils;
import com.ruoyi.common.core.utils.uuid.IdUtils;
import com.ruoyi.common.datascope.annotation.DataScopeMutiDept;
import com.ruoyi.common.datascope.base.service.BaseService;
import com.ruoyi.common.security.utils.SecurityUtils;
import com.sooka.sponest.event.emergency.danger.domain.CentereventTEmergencyDanger;
import com.sooka.sponest.event.emergency.dangerprocess.domain.CentereventTEmergencyDangerprocess;
import com.sooka.sponest.event.emergency.dangerprocess.domain.DayBody;
import com.sooka.sponest.event.emergency.dangerprocess.mapper.CentereventTEmergencyDangerprocessMapper;
import com.sooka.sponest.event.emergency.dangerprocess.service.ICentereventTEmergencyDangerprocessService;
import com.sooka.sponest.event.utils.RemoteApiUtil;
import org.apache.commons.collections4.MapUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

/**
 * 隐患处理过程Service业务层处理
 *
 * @author ruoyi
 * @date 2022-07-20
 */
@Service
public class CentereventTEmergencyDangerprocessServiceImpl extends BaseService implements ICentereventTEmergencyDangerprocessService {

    protected final Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private CentereventTEmergencyDangerprocessMapper centereventTEmergencyDangerprocessMapper;

    /**
     * 查询隐患处理过程列表
     *
     * @param centereventTEmergencyDangerprocess 隐患处理过程
     * @return 隐患处理过程
     */
    @Override
    public List<CentereventTEmergencyDangerprocess> selectCentereventTEmergencyDangerprocessList(CentereventTEmergencyDangerprocess centereventTEmergencyDangerprocess) {
        return centereventTEmergencyDangerprocessMapper.selectCentereventTEmergencyDangerprocessList(centereventTEmergencyDangerprocess);
    }

    /**
     * 查询隐患处理过程
     *
     * @param pkId 隐患处理过程主键
     * @return 隐患处理过程
     */
    @Override
    public CentereventTEmergencyDangerprocess selectCentereventTEmergencyDangerprocessByPkId(String pkId) {
        return centereventTEmergencyDangerprocessMapper.selectCentereventTEmergencyDangerprocessByPkId(pkId);
    }

    /**
     * 新增隐患处理过程
     *
     * @param centereventTEmergencyDangerprocess 隐患处理过程
     * @return 结果
     */
    @Override
    public int insertCentereventTEmergencyDangerprocess(CentereventTEmergencyDangerprocess centereventTEmergencyDangerprocess) {
        centereventTEmergencyDangerprocess.setId(IdUtils.fastSimpleUUID());
        centereventTEmergencyDangerprocess.setCreateBy(SecurityUtils.getUserId().toString());
        centereventTEmergencyDangerprocess.setCreateTime(DateUtils.getNowDate());
        int result = centereventTEmergencyDangerprocessMapper.insertCentereventTEmergencyDangerprocess(centereventTEmergencyDangerprocess);
        if (result > 0) {
            // 发送消息
            RemoteApiUtil.getInstance().sendMessage(new HashSet<>(Arrays.asList(centereventTEmergencyDangerprocess.getTelphone())), "有安全隐患需要处理请查收", null, null);
        }
        return result;
    }

    @Override
    public int insertCentereventTEmergencyDangerprocess(CentereventTEmergencyDanger centereventTEmergencyDanger) {
        CentereventTEmergencyDangerprocess centereventTEmergencyDangerprocess = new CentereventTEmergencyDangerprocess();
        centereventTEmergencyDangerprocess.setDangerId(centereventTEmergencyDanger.getId());
        centereventTEmergencyDangerprocess.setUserId(SecurityUtils.getUserId());
        centereventTEmergencyDangerprocess.setUserName(SecurityUtils.getLoginUser().getSysUser().getNickName());
        if ("trouble_status_2".equals(centereventTEmergencyDanger.getDangerStatus())) {
            centereventTEmergencyDangerprocess.setProcessDes(SecurityUtils.getLoginUser().getSysUser().getNickName() + "申请" + centereventTEmergencyDanger.getDangerStatusLabel());
        } else {
            centereventTEmergencyDangerprocess.setProcessDes(SecurityUtils.getLoginUser().getSysUser().getNickName() + "申请" + centereventTEmergencyDanger.getDangerStatusLabel() + "。" + centereventTEmergencyDanger.getDangerContent());
        }
        centereventTEmergencyDangerprocess.setTelphone(centereventTEmergencyDanger.getTelphone());
        return this.insertCentereventTEmergencyDangerprocess(centereventTEmergencyDangerprocess);
    }

    /**
     * 修改隐患处理过程
     *
     * @param centereventTEmergencyDangerprocess 隐患处理过程
     * @return 结果
     */
    @Override
    public int updateCentereventTEmergencyDangerprocess(CentereventTEmergencyDangerprocess centereventTEmergencyDangerprocess) {
        centereventTEmergencyDangerprocess.setUpdateTime(DateUtils.getNowDate());
        return centereventTEmergencyDangerprocessMapper.updateCentereventTEmergencyDangerprocess(centereventTEmergencyDangerprocess);
    }

    /**
     * 批量删除隐患处理过程
     *
     * @param pkIds 需要删除的隐患处理过程主键
     * @return 结果
     */
    @Override
    public int deleteCentereventTEmergencyDangerprocessByPkIds(String[] pkIds) {
        return centereventTEmergencyDangerprocessMapper.deleteCentereventTEmergencyDangerprocessByPkIds(pkIds);
    }

    /**
     * 热力地图
     *
     * @param dayBody
     * @return
     */
    @DataScopeMutiDept(deptAlias = "c", userAlias = "e")
    @Override
    public List getHeatMap(DayBody dayBody) {
        setSookaDataBase(dayBody);
        List<Map> latLngs = centereventTEmergencyDangerprocessMapper.getHeatMap(dayBody);
        List<Long> latLng;
        List list = new ArrayList();
        for (Map<String, Object> map : latLngs) {
            latLng = new ArrayList<>();
            latLng.add(MapUtils.getLong(map, "latitude"));
            latLng.add(MapUtils.getLong(map, "longitude"));
            latLng.add(1L);
            list.add(latLng);
        }
        return list;
    }
}
