package com.sooka.sponest.event.emergency.patrolrecord.controller;

import com.ruoyi.common.core.utils.StringUtils;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.sooka.sponest.event.emergency.patrolrecord.domain.CentereventTEmergencyPatrolrecord;
import com.sooka.sponest.event.emergency.patrolrecord.mapper.CentereventTEmergencyPatrolrecordMapper;
import com.sooka.sponest.event.emergency.patrolrecord.service.ICentereventTEmergencyPatrolrecordService;
import com.sooka.sponest.event.remoteapi.RemoteDataService;
import com.sooka.sponest.event.remoteapi.domain.CenterdataTEmergencyPatrolpoint;
import com.sooka.sponest.event.utils.ExcelUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 巡更记录Controller
 *
 * @author ruoyi
 * @date 2022-07-20
 */
@RestController
@RequestMapping("/patrolrecord")
public class CentereventTEmergencyPatrolrecordController extends BaseController {

    @Autowired
    private ICentereventTEmergencyPatrolrecordService centereventTEmergencyPatrolrecordService;

    @Autowired
    CentereventTEmergencyPatrolrecordMapper centereventTEmergencyPatrolrecordMapper;

    @Autowired
    private RemoteDataService remoteDataService;

    /**
     * 查询巡更记录列表
     */
    @RequiresPermissions("patrolrecord:patrolrecord:list")
    @GetMapping("/list")
    public TableDataInfo list(CentereventTEmergencyPatrolrecord centereventTEmergencyPatrolrecord) {
        startPage();
        List<CentereventTEmergencyPatrolrecord> list = centereventTEmergencyPatrolrecordService.selectCentereventTEmergencyPatrolrecordList(centereventTEmergencyPatrolrecord);
        return getDataTable(list);
    }

    @PostMapping("/listPatrolrecord")
    public TableDataInfo listPatrolrecord(@RequestBody CentereventTEmergencyPatrolrecord centereventTEmergencyPatrolrecord) {
        startPage();
        List<CentereventTEmergencyPatrolrecord> list = centereventTEmergencyPatrolrecordService.selectCentereventTEmergencyPatrolrecordList(centereventTEmergencyPatrolrecord);
        return getDataTable(list);
    }

    /**
     * 导出巡更记录列表
     */
    @RequiresPermissions("patrolrecord:patrolrecord:export")
    @Log(title = "巡更记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CentereventTEmergencyPatrolrecord centereventTEmergencyPatrolrecord) {
        List<CentereventTEmergencyPatrolrecord> list = centereventTEmergencyPatrolrecordService.selectCentereventTEmergencyPatrolrecordList(centereventTEmergencyPatrolrecord);
        ExcelUtil<CentereventTEmergencyPatrolrecord> util = new ExcelUtil<>(CentereventTEmergencyPatrolrecord.class);
        util.exportExcel(response, list, "巡更记录数据");
    }

    /**
     * 获取巡更记录详细信息
     */
//    @RequiresPermissions("patrolrecord:patrolrecord:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id) {
        return AjaxResult.success(centereventTEmergencyPatrolrecordService.selectCentereventTEmergencyPatrolrecordById(id));
    }

    /**
     * 新增巡更记录
     */
    @RequiresPermissions("patrolrecord:patrolrecord:add")
    @Log(title = "巡更记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CentereventTEmergencyPatrolrecord centereventTEmergencyPatrolrecord) {
        return toAjax(centereventTEmergencyPatrolrecordService.insertCentereventTEmergencyPatrolrecord(centereventTEmergencyPatrolrecord));
    }

    @PostMapping(value = "addPatrolrecord")
    public AjaxResult addPatrolrecord(@RequestBody CentereventTEmergencyPatrolrecord centereventTEmergencyPatrolrecord) {
        String barCode = centereventTEmergencyPatrolrecord.getPatrolpointId();
        CenterdataTEmergencyPatrolpoint info = remoteDataService.findIPatrolpointByBarCode(barCode).getData();
        if(info != null && StringUtils.isNotEmpty(info.getId())){
            return toAjax(centereventTEmergencyPatrolrecordService.insertCentereventTEmergencyPatrolrecord(centereventTEmergencyPatrolrecord));
        }else{
            return AjaxResult.error("暂无条形码信息");
        }
    }

    /**
     * 修改巡更记录
     */
    @RequiresPermissions("patrolrecord:patrolrecord:edit")
    @Log(title = "巡更记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CentereventTEmergencyPatrolrecord centereventTEmergencyPatrolrecord) {
        return toAjax(centereventTEmergencyPatrolrecordService.updateCentereventTEmergencyPatrolrecord(centereventTEmergencyPatrolrecord));
    }

    @PostMapping("/updatePatrolrecord")
    public void updatePatrolrecord(@RequestBody CentereventTEmergencyPatrolrecord centereventTEmergencyPatrolrecord) {
        centereventTEmergencyPatrolrecordMapper.updateCentereventTEmergencyPatrolrecord(centereventTEmergencyPatrolrecord);
    }

    /**
     * 删除巡更记录
     */
    @RequiresPermissions("patrolrecord:patrolrecord:remove")
    @Log(title = "巡更记录", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids) {
        return toAjax(centereventTEmergencyPatrolrecordService.deleteCentereventTEmergencyPatrolrecordByIds(ids));
    }

    /**
     * 根据人员查询人员轨迹日期
     * @Version 1.0
     * @return
     * @author wang_xy
     * @since 2023/3/27 20:27
     */
    @GetMapping("/findItudeByUserId/{userId}")
    public AjaxResult findItudeByUserId(@PathVariable("userId") String userId) {
        return centereventTEmergencyPatrolrecordService.findItudeByUserId(userId);
    }

    /**
     * 根据人员和时间段查询轨迹集合
     * @Version 1.0
     * @return
     * @author wang_xy
     * @since 2023/3/27 20:27
     */
    @GetMapping("/findItudeByUserIdAndTime/{userId}/{time}")
    public AjaxResult findItudeByUserIdAndTime(@PathVariable("userId") String userId,@PathVariable("time") String time) {
        return centereventTEmergencyPatrolrecordService.findItudeByUserIdAndTime(userId,time);
    }
}
